@@ -216,8 +216,8 @@ class RoboMakerClient(BaseClient):
         *,
         clientRequestToken: str,
         fleet: str,
-        deploymentApplicationConfigs: Sequence["DeploymentApplicationConfigTypeDef"],
-        deploymentConfig: "DeploymentConfigTypeDef" = ...,
+        deploymentApplicationConfigs: Sequence[DeploymentApplicationConfigTypeDef],
+        deploymentConfig: DeploymentConfigTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateDeploymentJobResponseTypeDef:
         """
@@ -256,10 +256,10 @@ class RoboMakerClient(BaseClient):
         self,
         *,
         name: str,
-        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
-        sources: Sequence["SourceConfigTypeDef"] = ...,
+        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
+        sources: Sequence[SourceConfigTypeDef] = ...,
         tags: Mapping[str, str] = ...,
-        environment: "EnvironmentTypeDef" = ...
+        environment: EnvironmentTypeDef = ...
     ) -> CreateRobotApplicationResponseTypeDef:
         """
         Creates a robot application.
@@ -287,12 +287,12 @@ class RoboMakerClient(BaseClient):
         self,
         *,
         name: str,
-        simulationSoftwareSuite: "SimulationSoftwareSuiteTypeDef",
-        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
-        sources: Sequence["SourceConfigTypeDef"] = ...,
-        renderingEngine: "RenderingEngineTypeDef" = ...,
+        simulationSoftwareSuite: SimulationSoftwareSuiteTypeDef,
+        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
+        sources: Sequence[SourceConfigTypeDef] = ...,
+        renderingEngine: RenderingEngineTypeDef = ...,
         tags: Mapping[str, str] = ...,
-        environment: "EnvironmentTypeDef" = ...
+        environment: EnvironmentTypeDef = ...
     ) -> CreateSimulationApplicationResponseTypeDef:
         """
         Creates a simulation application.
@@ -322,15 +322,15 @@ class RoboMakerClient(BaseClient):
         maxJobDurationInSeconds: int,
         iamRole: str,
         clientRequestToken: str = ...,
-        outputLocation: "OutputLocationTypeDef" = ...,
-        loggingConfig: "LoggingConfigTypeDef" = ...,
+        outputLocation: OutputLocationTypeDef = ...,
+        loggingConfig: LoggingConfigTypeDef = ...,
         failureBehavior: FailureBehaviorType = ...,
-        robotApplications: Sequence["RobotApplicationConfigTypeDef"] = ...,
-        simulationApplications: Sequence["SimulationApplicationConfigTypeDef"] = ...,
-        dataSources: Sequence["DataSourceConfigTypeDef"] = ...,
+        robotApplications: Sequence[RobotApplicationConfigTypeDef] = ...,
+        simulationApplications: Sequence[SimulationApplicationConfigTypeDef] = ...,
+        dataSources: Sequence[DataSourceConfigTypeDef] = ...,
         tags: Mapping[str, str] = ...,
-        vpcConfig: "VPCConfigTypeDef" = ...,
-        compute: "ComputeTypeDef" = ...
+        vpcConfig: VPCConfigTypeDef = ...,
+        compute: ComputeTypeDef = ...
     ) -> CreateSimulationJobResponseTypeDef:
         """
         Creates a simulation job.
@@ -343,7 +343,7 @@ class RoboMakerClient(BaseClient):
         self,
         *,
         worlds: Sequence[str],
-        outputLocation: "OutputLocationTypeDef",
+        outputLocation: OutputLocationTypeDef,
         iamRole: str,
         clientRequestToken: str = ...,
         tags: Mapping[str, str] = ...
@@ -359,7 +359,7 @@ class RoboMakerClient(BaseClient):
         self,
         *,
         template: str,
-        worldCount: "WorldCountTypeDef",
+        worldCount: WorldCountTypeDef,
         clientRequestToken: str = ...,
         tags: Mapping[str, str] = ...,
         worldTags: Mapping[str, str] = ...
@@ -377,7 +377,7 @@ class RoboMakerClient(BaseClient):
         clientRequestToken: str = ...,
         name: str = ...,
         templateBody: str = ...,
-        templateLocation: "TemplateLocationTypeDef" = ...,
+        templateLocation: TemplateLocationTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateWorldTemplateResponseTypeDef:
         """
@@ -560,11 +560,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_deployment_jobs(
-        self,
-        *,
-        filters: Sequence["FilterTypeDef"] = ...,
-        nextToken: str = ...,
-        maxResults: int = ...
+        self, *, filters: Sequence[FilterTypeDef] = ..., nextToken: str = ..., maxResults: int = ...
     ) -> ListDeploymentJobsResponseTypeDef:
         """
         Returns a list of deployment jobs for a fleet.
@@ -574,11 +570,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_fleets(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., filters: Sequence[FilterTypeDef] = ...
     ) -> ListFleetsResponseTypeDef:
         """
         Returns a list of fleets.
@@ -593,7 +585,7 @@ class RoboMakerClient(BaseClient):
         versionQualifier: str = ...,
         nextToken: str = ...,
         maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        filters: Sequence[FilterTypeDef] = ...
     ) -> ListRobotApplicationsResponseTypeDef:
         """
         Returns a list of robot application.
@@ -603,11 +595,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_robots(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., filters: Sequence[FilterTypeDef] = ...
     ) -> ListRobotsResponseTypeDef:
         """
         Returns a list of robots.
@@ -622,7 +610,7 @@ class RoboMakerClient(BaseClient):
         versionQualifier: str = ...,
         nextToken: str = ...,
         maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        filters: Sequence[FilterTypeDef] = ...
     ) -> ListSimulationApplicationsResponseTypeDef:
         """
         Returns a list of simulation applications.
@@ -632,11 +620,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_simulation_job_batches(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., filters: Sequence[FilterTypeDef] = ...
     ) -> ListSimulationJobBatchesResponseTypeDef:
         """
         Returns a list simulation job batches.
@@ -646,11 +630,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_simulation_jobs(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., filters: Sequence[FilterTypeDef] = ...
     ) -> ListSimulationJobsResponseTypeDef:
         """
         Returns a list of simulation jobs.
@@ -668,11 +648,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_world_export_jobs(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., filters: Sequence[FilterTypeDef] = ...
     ) -> ListWorldExportJobsResponseTypeDef:
         """
         Lists world export jobs.
@@ -682,11 +658,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_world_generation_jobs(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., filters: Sequence[FilterTypeDef] = ...
     ) -> ListWorldGenerationJobsResponseTypeDef:
         """
         Lists world generator jobs.
@@ -706,11 +678,7 @@ class RoboMakerClient(BaseClient):
         """
 
     def list_worlds(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filters: Sequence["FilterTypeDef"] = ...
+        self, *, nextToken: str = ..., maxResults: int = ..., filters: Sequence[FilterTypeDef] = ...
     ) -> ListWorldsResponseTypeDef:
         """
         Lists worlds.
@@ -738,9 +706,9 @@ class RoboMakerClient(BaseClient):
     def start_simulation_job_batch(
         self,
         *,
-        createSimulationJobRequests: Sequence["SimulationJobRequestTypeDef"],
+        createSimulationJobRequests: Sequence[SimulationJobRequestTypeDef],
         clientRequestToken: str = ...,
-        batchPolicy: "BatchPolicyTypeDef" = ...,
+        batchPolicy: BatchPolicyTypeDef = ...,
         tags: Mapping[str, str] = ...
     ) -> StartSimulationJobBatchResponseTypeDef:
         """
@@ -780,10 +748,10 @@ class RoboMakerClient(BaseClient):
         self,
         *,
         application: str,
-        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
-        sources: Sequence["SourceConfigTypeDef"] = ...,
+        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
+        sources: Sequence[SourceConfigTypeDef] = ...,
         currentRevisionId: str = ...,
-        environment: "EnvironmentTypeDef" = ...
+        environment: EnvironmentTypeDef = ...
     ) -> UpdateRobotApplicationResponseTypeDef:
         """
         Updates a robot application.
@@ -796,12 +764,12 @@ class RoboMakerClient(BaseClient):
         self,
         *,
         application: str,
-        simulationSoftwareSuite: "SimulationSoftwareSuiteTypeDef",
-        robotSoftwareSuite: "RobotSoftwareSuiteTypeDef",
-        sources: Sequence["SourceConfigTypeDef"] = ...,
-        renderingEngine: "RenderingEngineTypeDef" = ...,
+        simulationSoftwareSuite: SimulationSoftwareSuiteTypeDef,
+        robotSoftwareSuite: RobotSoftwareSuiteTypeDef,
+        sources: Sequence[SourceConfigTypeDef] = ...,
+        renderingEngine: RenderingEngineTypeDef = ...,
         currentRevisionId: str = ...,
-        environment: "EnvironmentTypeDef" = ...
+        environment: EnvironmentTypeDef = ...
     ) -> UpdateSimulationApplicationResponseTypeDef:
         """
         Updates a simulation application.
@@ -816,7 +784,7 @@ class RoboMakerClient(BaseClient):
         template: str,
         name: str = ...,
         templateBody: str = ...,
-        templateLocation: "TemplateLocationTypeDef" = ...
+        templateLocation: TemplateLocationTypeDef = ...
     ) -> UpdateWorldTemplateResponseTypeDef:
         """
         Updates a world template.
